@@ -1,6 +1,6 @@
 package App::perlmv::scriptlets::std;
 BEGIN {
-  $App::perlmv::scriptlets::std::VERSION = '0.41';
+  $App::perlmv::scriptlets::std::VERSION = '0.42';
 }
 # ABSTRACT: A collection of perlmv scriptlets
 
@@ -14,6 +14,12 @@ s/\s{2,}/ /g; $_
 EOT
 
 
+$scriptlets{'keep-one-ext'} = <<'EOT';
+### Summary: Remove all but the last file extension if there are more than one, e.g. (1.tar, 2.mp3.mp3) -> (1.tar, 2.mp3)
+s/(.+?)(?:\.\w{1,5})+(\.\w{1,5})$/$1$2/
+EOT
+
+
 $scriptlets{'pinyin'} = <<'EOT';
 ### Summary: Rename Chinese characters in filename into their pinyin
 ### Requires: Lingua::Han::Pinyin
@@ -52,6 +58,18 @@ $_
 EOT
 
 
+$scriptlets{'remove-ext'} = <<'EOT';
+### Summary: Remove the last file extension, e.g. (1, 2.mp3, 3.tar.gz) -> (1, 2, 3.tar)
+s/(.+)\.\w{1,5}$/$1/
+EOT
+
+
+$scriptlets{'remove-all-ext'} = <<'EOT';
+### Summary: Remove all file extensions, e.g. (file.html.gz) -> (file)
+s/(.+?)(?:\.\w{1,5})+$/$1/
+EOT
+
+
 $scriptlets{'to-number'} = <<'EOT';
 ### Summary: Rename files into numbers. Ex: (file1.txt, foo.jpg, quux.mpg) -> (1, 2, 3)
 if ($COMPILING || $CLEANING) { $i=0 } else { $i++ }
@@ -110,7 +128,7 @@ App::perlmv::scriptlets::std - A collection of perlmv scriptlets
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 SCRIPTLETS
 
@@ -119,6 +137,12 @@ version 0.41
 Replace multiple spaces into a single space, example (<space>
 signifies actual space): "1<space><space>2.txt " -> "1<space>2.txt"
 
+=head2 keep-one-ext
+
+Remove all but the last file extension if there are more than one, e.g. (1.tar,
+2.mp3.mp3) -> (1.tar, 2.mp3). TODO: treat tar.gz/tar.bz2/etc as one
+extension.
+
 =head2 pinyin
 
 Rename Chinese characters in filename into their pinyin. Requires
@@ -134,6 +158,14 @@ Remove prefix that are common to all args, e.g. (file1, file2b) -> (1,
 Remove suffix that are common to all args, while preserving extension,
 e.g. (1-radiolab.mp3, 2-radiolab.mp3) -> (1.mp3, 2.mp3)
 
+=head2 remove-ext
+
+Remove the last file extension, e.g. (1, 2.mp3, 3.tar.gz) -> (1, 2, 3.tar)
+
+=head2 remove-all-ext
+
+Remove all file extensions, e.g. (file.html.gz) -> (file)
+
 =head2 to-number
 
 Rename files into numbers. Ex: (file1.txt, foo.jpg, quux.mpg) -> (1.txt, 2.jpg,
@@ -175,7 +207,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Steven Haryanto.
+This software is copyright (c) 2011 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
